@@ -56,16 +56,17 @@ sub add {
 	my @paragraphs = split /\n/, $self->text;
 	my $space = $text->advancewidth(" ");
 
-	my $next_line = shift @paragraphs;
-	my @words = split(/ /, $next_line);
-	push @words, $1 if $next_line !~ m/^\s+$/ && $next_line =~ m/(\s+)$/;
-	push @words, $next_line unless scalar @words;
-
-	if ($indent) {
-		unshift @words, map { " " } 0 .. $indent;
-	}
-	
-	while ($ypos - $pos{l} >= $max_height && @words) {
+	my @words;	
+	while ($ypos - $pos{l} >= $max_height && (scalar @paragraphs || scalar @words)) {
+		unless (scalar @words) {
+			my $next_line = shift @paragraphs;
+			@words = split(/ /, $next_line);
+			push @words, $1 if $next_line !~ m/^\s+$/ && $next_line =~ m/(\s+)$/;
+			push @words, $next_line unless scalar @words;
+			if ($indent) {
+				unshift @words, map { "" } 0 .. $indent;
+			}
+		}
 		my $word = shift @words; 
 		$word =~ s/\t/         /g;		
 		my ($width, @line) = ($text->advancewidth($word), ());
@@ -92,12 +93,11 @@ sub add {
 
 		my $align = $self->align;
 		if ($align eq 'center') {
-			$xpos = $xpos + ((($pos{w} - $width) / 2) -  ($width / 2));
+			$xpos = $xpos + (($pos{w} - $width) / 2);
 		} elsif ($align eq 'right') {
 			$xpos = $xpos + ($pos{w} - $width);
 			$self->end_w($xpos + $pos{w});
 		}
-
 		$text->translate($xpos, $ypos);
 		$text->text(join(" ", @line));
 		$ypos -= $pos{l};
@@ -105,9 +105,13 @@ sub add {
 
 	$file->page->y($file->page->h - (($ypos + $pos{l}) - $self->margin));
 
-	if (!$self->overflow && scalar @words) {
+	if (scalar @words) {
+		push @paragraphs, join " ", @words;
+	}
+
+	if (!$self->overflow && scalar @paragraphs) {
 		$file->page->next($file);
-		return $self->add($file, text => join " ", @words);
+		return $self->add($file, text => join "\n", @paragraphs);
 	}
 
 	return $file;
