@@ -2,11 +2,15 @@ package Khonsu::Text::H4;
 
 use parent 'Khonsu::Text';
 
+sub BUILD {
+	my ($self, %params) = @_;
+	$self->font->size($params{font_size} || 25);
+	$self->font->line_height($params{line_height} || 17);
+}
+
 sub add {
 	my ($self, $file, %attributes) = @_;
-	$attributes{font}->{size} ||= 25;
-	$attributes{font}->{line_height} ||= 17;
-	$attributes{h} ||= $attributes{font}->{line_height};
+	$attributes{h} ||= $self->font->size;
 	$file->toc->outline($file, 'h4', %attributes) if $attributes{toc};
 	return $self->SUPER::add($file, %attributes);
 }
